@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 # =============================================================================
 # @file   plotting.py
 # @author Albert Puig (albert.puig@cern.ch)
@@ -18,8 +17,12 @@ def make_norm_histo(array, range_, weights=None):
 
 def mass(vector):
     """Calculate mass scalar for Lorentz 4-momentum."""
-    return np.sqrt(np.sum(vector * vector * np.reshape(np.array([-1., -1., -1., 1.]),
-                                                       (1, 4)),
-                          axis=1))
+    return np.sqrt(
+        np.sum(
+            vector * vector * np.reshape(np.array([-1.0, -1.0, -1.0, 1.0]), (1, 4)),
+            axis=1,
+        )
+    )
+
 
 # EOF
